@@ -1,23 +1,16 @@
 #' Calculate the auto-correlation time using only R. Consider using
 #' \link{calc_act} instead, as it is orders of magnitude faster
-#' @param trace the values
-#' @param sample_interval the interval in timesteps between samples
+#' @inheritParams default_params_doc
 #' @return the auto correlation time
 #' @examples
-#'   trace <- sin(seq(from = 0.0, to = 2.0 * pi, length.out = 100))
-#'   act <- calc_act_r(
-#'     trace = trace,
-#'     sample_interval = 1
-#'   )
-#'   testthat::expect_equal(object = act, expected = 38.18202, tolerance = 0.01)
+#' trace <- sin(seq(from = 0.0, to = 2.0 * pi, length.out = 100))
+#' calc_act_r(trace = trace, sample_interval = 1) # 38.18202
 #' @export
 #' @seealso Java code can be found here: \url{https://github.com/CompEvol/beast2/blob/9f040ed0357c4b946ea276a481a4c654ad4fff36/src/beast/core/util/ESS.java#L161} # nolint URLs can be long
 #' @author The original Java version of the algorithm was from Remco Bouckaert,
 #'   ported to R and adapted by Richèl J.C. Bilderbeek
 calc_act_r <- function(trace, sample_interval) {
-  if (!is.numeric(trace)) {
-    stop("trace must be numeric")
-  }
+  tracerer::check_trace(trace)
   if (sample_interval < 1) {
     stop("sample interval must be at least one")
   }
@@ -98,19 +91,14 @@ NULL
 #' @return the auto_correlation time
 #' @export
 #' @examples
-#'   trace <- sin(seq(from = 0.0, to = 2.0 * pi, length.out = 100))
-#'   act <- calc_act(
-#'     trace = trace,
-#'     sample_interval = 1
-#'   )
-#'   testthat::expect_equal(object = act, expected = 38.18202, tolerance = 0.01)
+#' trace <- sin(seq(from = 0.0, to = 2.0 * pi, length.out = 100))
+#' # 38.18202
+#' calc_act(trace = trace, sample_interval = 1)
 #' @seealso Java code can be found here: \url{https://github.com/CompEvol/beast2/blob/9f040ed0357c4b946ea276a481a4c654ad4fff36/src/beast/core/util/ESS.java#L161} # nolint URLs can be long
 #' @author The original Java version of the algorithm was from Remco Bouckaert,
 #'   ported to R and adapted by Richèl J.C. Bilderbeek
 calc_act <- function(trace, sample_interval) {
-  if (!is.numeric(trace)) {
-    stop("trace must be numeric")
-  }
+  tracerer::check_trace(trace)
   if (sample_interval < 1) {
     stop("sample interval must be at least one")
   }
