@@ -4,20 +4,15 @@
 #' @return the values with the burn-in removed
 #' @export
 #' @examples
-#'   # Create a trace from one to and including ten
-#'   v <- seq(1, 10)
+#' # Create a trace from one to and including ten
+#' v <- seq(1, 10)
 #'
-#'   # Remove the first ten percent of its values,
-#'   # in this case removes the first value, which is one
-#'   w <- remove_burn_in(trace = v, burn_in_fraction = 0.1)
-#'
-#'   # Check that the result goes from two to ten
-#'   testit::assert(w == seq(2, 10))
+#' # Remove the first ten percent of its values,
+#' # in this case removes the first value, which is one
+#' w <- remove_burn_in(trace = v, burn_in_fraction = 0.1)
 #' @author Richèl J.C. Bilderbeek
 remove_burn_in <- function(trace, burn_in_fraction) {
-  if (!is.numeric(trace)) {
-    stop("'trace' must be numeric")
-  }
+  tracerer::check_trace(trace)
   if (burn_in_fraction < 0.0) {
     stop("'burn_in_fraction' must be at least zero")
   }
